checkRequire("Lua_ArenaRankModelItem");
Lua_ArenaRankPanel = class("Lua_ArenaRankPanel", Lua_DisplayObject);
function Lua_ArenaRankPanel:ctor(p)
	self:superCall("ctor", p, "ArenaRankPanel_skin");
end

function Lua_ArenaRankPanel:buildPanel(go)
	self:superCall("buildPanel", go);

	self:addLuaEvent("UPDATE_ARENA_RANK", self, self.updateShowInfo);
	self:addLuaEvent("UPDATE_SINGLE_ARENA_RANK", self, self.updateSingleInfo);
end

function Lua_ArenaRankPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rankBg_1:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 718 + self.adaptHeight);
	self.rankBg_2:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 554 + self.adaptHeight);

	self.itemList = Lua_DragList.new(self.content, 690, 538 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_ArenaRankItem, 690, 123, 1);
	self.itemList:setLocation(0, -177, 0);
	self.itemList:setCellSpacing(0, 10);

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-160, 195, 0);
	self.avatarItem:setRectAnchor(7);

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-282, 192, 0);
	self.rankNum:setRectAnchor(7);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -5;
	self.rankNum.numAtlas = "number";
	self.rankNum.lastStr = nil;
	self.rankNum.preStr = "ui_djc2_title_0";

	self.sprLike:addClickFuntion(self, self.onLikeClick);

	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sRankInfo();
end

function Lua_ArenaRankPanel:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	if self.itemArr ~= nil then
		self.itemArr:dispose();
		self.itemArr:clear();
		self.itemArr = nil;
	end
	if self.modelArr ~= nil then
		self.modelArr:dispose();
		self.modelArr:clear();
		self.modelArr = nil;
	end
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ArenaRankPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	self.rankBg_1:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 718 + adaptHeight);
	self.rankBg_2:SetDimensions(MainWinDefine.DEFAULT_WIDTH, 554 + adaptHeight);
	self.itemList:setContentRect(690, 540 + adaptHeight);
end

function Lua_ArenaRankPanel:updateShowInfo(msg)
	if msg == nil then
		return;
	end
	self:updateLikeTimes(msg.like_times);

	if self.rankArr == nil then
		self.rankArr = Array();
	end
	if self.modelArr == nil then
		self.modelArr = Array();
	end

	local obj;
	for i = 1, #msg.rank_list do
		obj = msg.rank_list[i];
		if obj.rank > 3 then
			self.rankArr:add(obj);
		else
			self.modelArr:add(obj);
		end
	end
	self.rankArr:sort("rank", false);
	self.modelArr:sort("rank", false);
	self.itemList:setArrayData(self.rankArr);

	self:updateModelInfo();
	self:updateSelfInfo(msg.self_rank);
end

function Lua_ArenaRankPanel:updateSingleInfo(msg)
	if msg == nil then
		return;
	end
	self:updateLikeTimes(msg.like_num);

	-- 自己
	if self.data.player_id == msg.role.player_id then
		self:updateSelfInfo(msg.role);
	else
		for i = 1, self.rankArr:getSize() do
			if self.rankArr[i].player_id == msg.role.player_id then
				self.rankArr[i] = msg.role;
				break;
			end
		end
		self.itemList:setArrayData(self.rankArr);
	end

	for i = 1, self.modelArr:getSize() do
		if self.modelArr[i].player_id == msg.role.player_id then
			self.modelArr[i] = msg.role;
			break;
		end
	end
	self:updateModelInfo();
end

function Lua_ArenaRankPanel:updateModelInfo()
	local posTab = {{0, -370}, {-245, -403}, {245, -403}};
	if self.itemArr == nil then
		self.itemArr = Array();
	end
	local item;
	for i = 1, 3 do
		item = self.itemArr[i];
		if item == nil then
			item = Lua_ArenaRankModelItem.new(self.content);
			self.itemArr:add(item);
		end
		item:setRectAnchor(4);
		item:setLocation(posTab[i][1], posTab[i][2], 0);
		item:setRectAnchor(1);
		item:setData(i, self.modelArr[i]);
	end
end

function Lua_ArenaRankPanel:updateLikeTimes(like_times)
	local limitTimes = DataCenter.arenaUtil:getConstConfig("like_limit_times", 1);
	DataCenter.arenaData.likeTimes = like_times;
	local str = like_times.."/"..limitTimes;
	if like_times > 0 then
		str = Lua_ColorDefine.getColorStr("00BB04", str);
	end
	self.txtLikeNum.text = LanUtil.formateStr(303013, str);
end

function Lua_ArenaRankPanel:updateSelfInfo(data)
	self.data = data;

	self.avatarItem:setRoleAvatar(data.head_id);
	self.avatarItem:setRoleLevel(data.level);
	self.txtSelfName.text = data.name;
	self.txtSelfIntegral.text = data.score;
	self.txtSelfLikeNum.text = data.like_num;
	self.txtRank:setEnable(data.rank <= 0);
	if data.rank > 0 then
		self.rankNum:setEnable(true);
		self.rankNum.num = data.rank;
	else
		self.rankNum:setEnable(false);
	end
	
	local selfRank = DataCenter.arenaData.self_rank;
	if selfRank ~= data.rank then
		DataCenter.arenaData.self_rank = data.rank;
	end

	if data.like_state == 1 then
		self.sprLike:setAltas("common_altas_2", "ui_common_button_037_n");
	else
		self.sprLike:setAltas("common_altas_2", "ui_common_button_038_n");
	end
end

function Lua_ArenaRankPanel:onLikeClick(go)
	if self.data == nil then
		return;
	end
	if DataCenter.roleData:isMyself(self.data.player_id) then
		OperateAlert.showLangValue(303030);
		return;
	end
	if DataCenter.arenaData.likeTimes <= 0 then
		OperateAlert.showLangValue(303022);
		return;
	end
	if self.data.like_state == 1 then
		OperateAlert.showLangValue(303023);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sLikePlayer(self.data.player_id);
end




















Lua_ArenaRankItem = class("Lua_ArenaRankItem", Lua_ListCell);
function Lua_ArenaRankItem:ctor(p)
	self:superCall("ctor", p, "ArenaRankItem_skin");
end

function Lua_ArenaRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-166, 0, 0);
	-- self.avatarItem:setCanClick(false);
	self.avatarItem:setAvatarClick(self, self.onAvatarClick);

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-282, 0, 0);
	self.rankNum.pivot = 0;
	self.rankNum.numOffsetX = -4;
	self.rankNum.numAtlas = "number";
	self.rankNum.lastStr = nil;
	self.rankNum.preStr = "ui_djc_title_0";

	self.sprLike:addClickFuntion(self, self.onLikeClick);
end

function Lua_ArenaRankItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ArenaRankItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.rankNum.num = data.rank;
	
	self.avatarItem:setRoleAvatar(data.head_id);
	self.avatarItem:setRoleLevel(data.level);
	self.txtRoleName.text = data.name;
	if strIsNullOrEmpty(data.league_name) then
		self.txtLeagueName:setLangValue(303020);
	else
		self.txtLeagueName.text = data.league_name;
	end
	self.txtIntegral.text = data.score;
	self.txtIikeNum.text = data.like_num;

	if data.like_state == 1 then
		self.sprLike:setAltas("common_altas_2", "ui_common_button_037_n");
	else
		self.sprLike:setAltas("common_altas_2", "ui_common_button_038_n");
	end
end

function Lua_ArenaRankItem:onAvatarClick()
	if self.data == nil then
		return;
	end

	if self.data.is_robot ~= 0 then
		OperateAlert.showLangValue(123657);
	else
		if DataCenter.roleData:isMyself(self.data.player_id) then
			OperateAlert.showLangValue(123656);
		else
			Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.player_id);
		end
	end
end

function Lua_ArenaRankItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	if DataCenter.roleData:isMyself(self.data.player_id) then
		OperateAlert.showLangValue(303030);
		return;
	end
	if DataCenter.arenaData.likeTimes <= 0 then
		OperateAlert.showLangValue(303022);
		return;
	end
	if self.data.like_state == 1 then
		OperateAlert.showLangValue(303023);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ArenaProxy"):sLikePlayer(self.data.player_id);
end